module Random.Pcg.Int exposing (..)

{-| Extra randomized functions on ints.

# Generators
@docs anyInt, positiveInt, negativeInt, intGreaterThan, intLessThan
-}

import Random.Pcg exposing (Generator, int, minInt, maxInt)


{-| A generator that generates any int that can be generated by the
random generator algorithm.
-}
anyInt : Generator Int
anyInt =
    int minInt maxInt


{-| A generator that generates a positive int
-}
positiveInt : Generator Int
positiveInt =
    int 1 maxInt


{-| A generator that generates a negative int
-}
negativeInt : Generator Int
negativeInt =
    int minInt -1


{-| A generator that generates an int greater than a given int
-}
intGreaterThan : Int -> Generator Int
intGreaterThan value =
    int (value + 1) maxInt


{-| A generator that generates an int less than a given int
-}
intLessThan : Int -> Generator Int
intLessThan value =
    int minInt (value - 1)
